import type { CSSProperties } from 'react';
import type { YAxisProps } from 'recharts';
import type { IChartBaseProps } from '../../interfaces/IChartBaseProps.js';
import type { IChartDimension } from '../../interfaces/IChartDimension.js';
import type { IChartMeasure } from '../../interfaces/IChartMeasure.js';
interface MeasureConfig extends IChartMeasure {
    /**
     * Bar Width
     * @default auto
     */
    width?: number;
    /**
     * Bar Opacity
     * @default 1
     */
    opacity?: number;
    /**
     * Bar Stack ID
     * @default undefined
     */
    stackId?: string;
    /**
     * Highlight color of defined elements
     * @param value {string | number} Current value of the highlighted measure
     * @param measure {IChartMeasure} Current measure object
     * @param dataElement {object} Current data element
     */
    highlightColor?: (value: number, measure: MeasureConfig, dataElement: Record<string, any>) => CSSProperties['color'];
}
interface DimensionConfig extends IChartDimension {
    /**
     * Interval of dimension axis labels
     */
    interval?: YAxisProps['interval'];
}
export interface BarChartProps extends IChartBaseProps {
    /**
     * An array of config objects. Each object will define one dimension of the chart.
     *
     * **Required Properties**
     * - `accessor`: string containing the path to the dataset key the dimension should display. Supports object structures by using <code>'parent.child'</code>.
     *   Can also be a getter.
     *
     * **Optional Properties**
     * - `formatter`: function will be called for each data label and allows you to format it according to your needs
     * - `interval`: number that controls how many ticks are rendered on the x axis
     *
     */
    dimensions: DimensionConfig[];
    /**
     * An array of config objects. Each object is defining one bar in the chart.
     *
     * **Required properties**
     * - `accessor`: string containing the path to the dataset key this bar should display. Supports object structures by using <code>'parent.child'</code>.
     *   Can also be a getter.
     *
     * **Optional properties**
     *
     * - `label`: Label to display in legends or tooltips. Falls back to the <code>accessor</code> if not present.
     * - `color`: any valid CSS Color or CSS Variable. Defaults to the `sapChart_OrderedColor_` colors
     * - `formatter`: function will be called for each data label and allows you to format it according to your needs
     * - `hideDataLabel`: flag whether the data labels should be hidden in the chart for this bar.
     * - `DataLabel`: a custom component to be used for the data label
     * - `width`: bar width, defaults to `auto`
     * - `opacity`: bar opacity, defaults to `1`
     * - `stackId`: bars with the same stackId will be stacked
     * - `highlightColor`: function will be called to define a custom color of a specific element which matches the
     *    defined condition. Overwrites code>color</code> of the element.
     *
     */
    measures: MeasureConfig[];
}
/**
 * A `BarChart` is a data visualization where each category is represented by a rectangle, with the width of the rectangle being proportional to the values being plotted.
 */
declare const BarChart: import("react").ForwardRefExoticComponent<BarChartProps & import("react").RefAttributes<HTMLDivElement>>;
export { BarChart };
