'use client';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { enrichEventWithDetails, ThemingParameters } from '@ui5/webcomponents-react-base';
import { forwardRef } from 'react';
import { PolarAngleAxis, RadialBar, RadialBarChart } from 'recharts';
import { useOnClickInternal } from '../../hooks/useOnClickInternal.js';
import { ChartContainer } from '../../internal/ChartContainer.js';
import { PieChartPlaceholder } from '../PieChart/Placeholder.js';
const radialBarBackground = { fill: ThemingParameters.sapContent_ImagePlaceholderBackground };
const defaultDisplayValueStyles = {
    fontSize: '1.25rem',
    fill: ThemingParameters.sapTextColor,
    fontFamily: ThemingParameters.sapFontFamily,
};
/**
 * Displays a ring chart highlighting a current status.
 * The status can be emphasized by using the `color` prop.
 */
const RadialChart = forwardRef((props, ref) => {
    const { loading, loadingDelay, maxValue = 100, value, displayValue, onDataPointClick, onClick, color, style, className, slot, noAnimation, chartConfig, displayValueStyle = defaultDisplayValueStyles, ...rest } = props;
    const range = [0, maxValue];
    const dataset = typeof value === 'number' ? [{ value }] : [];
    const onDataPointClickInternal = (payload, i, event) => {
        if (payload && onDataPointClick) {
            onDataPointClick(enrichEventWithDetails(event, {
                value: payload.value,
                payload: payload.payload,
                dataIndex: i,
            }));
        }
    };
    const onClickInternal = useOnClickInternal(onClick);
    return (_jsx(ChartContainer, { loading: loading, loadingDelay: loadingDelay, dataset: dataset, ref: ref, Placeholder: PieChartPlaceholder, className: className, slot: slot, resizeDebounce: 250, style: style, ...rest, children: _jsxs(RadialBarChart, { onClick: onClickInternal, innerRadius: "90%", outerRadius: "100%", barSize: 10, data: dataset, cx: "50%", cy: "50%", startAngle: 90, endAngle: -270, ...chartConfig, children: [_jsx(PolarAngleAxis, { type: "number", domain: range, tick: false }), _jsx(RadialBar, { isAnimationActive: !noAnimation, background: radialBarBackground, dataKey: "value", fill: color ?? ThemingParameters.sapChart_OrderedColor_1, onClick: onDataPointClickInternal }), displayValue && (_jsx("text", { x: "50%", y: "50%", textAnchor: "middle", dominantBaseline: "middle", className: "progress-label", style: { ...defaultDisplayValueStyles, ...displayValueStyle }, children: displayValue }))] }) }));
});
RadialChart.displayName = 'RadialChart';
export { RadialChart };
