import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { BusyIndicator, Label } from '@ui5/webcomponents-react';
import { useStylesheet } from '@ui5/webcomponents-react-base';
import { addCustomCSSWithScoping } from '@ui5/webcomponents-react-base/dist/utils/addCustomCSSWithScoping.js';
import { clsx } from 'clsx';
import { Component, forwardRef } from 'react';
import { ResponsiveContainer } from 'recharts';
import { classNames, styleData } from './ChartContainer.module.css.js';
//todo: add feature request for parts or even a fix if this turns out to be a bug
addCustomCSSWithScoping('ui5-busy-indicator', `
:host([data-component-name="ChartContainerBusyIndicator"]) .ui5-busy-indicator-busy-area{
    background:unset;
},
:host([data-component-name="ChartContainerBusyIndicator"]) .ui5-busy-indicator-busy-area:focus {
    border-radius: 0;
}
`);
class ErrorBoundary extends Component {
    constructor() {
        super(...arguments);
        this.state = {
            errorCount: 0,
        };
    }
    componentDidCatch() {
        if (this.state.errorCount < 3) {
            this.setState((old) => ({ ...old, errorCount: old.errorCount + 1 }));
        }
    }
    render() {
        if (this.state.errorCount >= 3) {
            return _jsx(Label, { children: "Sorry, something went wrong while rendering this chart!" });
        }
        return this.props.children;
    }
}
const ChartContainer = forwardRef((props, ref) => {
    const { Placeholder, loading = false, dataset, className, slot, children, resizeDebounce, loadingDelay, ...rest } = props;
    useStylesheet(styleData, ChartContainer.displayName);
    return (_jsx("div", { ref: ref, className: clsx(classNames.container, className), slot: slot, ...rest, children: dataset?.length > 0 ? (_jsxs(_Fragment, { children: [loading && (_jsx(BusyIndicator, { active: true, delay: loadingDelay, className: classNames.busyIndicator, "data-component-name": "ChartContainerBusyIndicator" })), _jsx(ErrorBoundary, { children: _jsx(ResponsiveContainer, { debounce: resizeDebounce, children: children }) })] })) : (_jsx(Placeholder, {})) }));
});
ChartContainer.displayName = 'ChartContainer';
export { ChartContainer };
